import { defineComponent, createVNode, resolveComponent, mergeProps } from 'vue';
import { ElButton, ElTooltip, ElMessageBox } from 'element-plus';
import { buttonProps } from './type.mjs';

var Button = defineComponent({
  name: "BcButton",
  emits: ["click"],
  props: buttonProps,
  components: {
    ElButton,
    ElTooltip
  },
  setup(props, context) {
    function handleClick(event) {
      if (props.confirm || props.type === "delete" || props.type === "danger") {
        const confirmText = typeof props.confirm === "boolean" ? "\u6B64\u64CD\u4F5C\u65E0\u6CD5\u64A4\u9500\uFF0C\u662F\u5426\u7EE7\u7EED\uFF1F" : props.confirm;
        ElMessageBox.confirm(confirmText, "\u8B66\u544A", {
          confirmButtonText: "\u786E\u5B9A",
          cancelButtonText: "\u53D6\u6D88",
          type: "warning"
        }).then(() => {
          context.emit("click", event);
        }).catch(() => ({}));
      } else {
        context.emit("click", event);
      }
    }
    const tooltip = (node) => createVNode(resolveComponent("el-tooltip"), {
      "placement": "top"
    }, {
      default: () => [createVNode("span", null, [node()])],
      content: () => {
        var _a, _b;
        return createVNode("span", null, [(_b = (_a = context.slots).default) == null ? void 0 : _b.call(_a)]);
      }
    });
    const spanContent = !props.tooltip ? context.slots.default || null : null;
    const button = () => createVNode(resolveComponent("el-button"), mergeProps({
      "class": ["bc-button", {
        mini: props.mini
      }]
    }, {
      ...context.attrs,
      type: props.type,
      tooltip: props.tooltip,
      onClick: handleClick
    }), {
      default: () => [createVNode("span", null, [spanContent == null ? void 0 : spanContent()])]
    });
    const iconButton = () => createVNode(resolveComponent("el-button"), mergeProps({
      "class": ["bc-button", {
        mini: props.mini
      }]
    }, {
      ...context.attrs,
      type: props.type,
      tooltip: props.tooltip,
      onClick: handleClick
    }), null);
    return () => context.slots.default && props.tooltip ? tooltip(iconButton) : context.attrs.icon ? iconButton() : button();
  }
});

export { Button as default };
//# sourceMappingURL=button.mjs.map
