import { defineComponent, computed, createVNode, resolveComponent, mergeProps } from 'vue';
import '../../../hooks/index.mjs';
import { useConfigInject } from '../../../hooks/useConfigInject.mjs';

var DatePicker = defineComponent({
  name: "BcDatePicker",
  props: {
    width: [String, Number],
    dayEnd: Boolean
  },
  setup(props, {
    attrs
  }) {
    const {
      datePicker
    } = useConfigInject("datePicker", props);
    const realWidth = computed(() => {
      if (typeof props.width === "string") {
        return props.width;
      } else {
        return `${props.width}px`;
      }
    });
    const type = computed(() => attrs.type);
    const timeRange = ["1111-11-11 00:00:00", "1111-11-11 23:59:59"];
    const rangeDefaultConfig = {
      startPlaceholder: "\u5F00\u59CB\u65F6\u95F4",
      endPlaceholder: "\u7ED3\u675F\u65F6\u95F4",
      rangeSeparator: "\u81F3",
      defaultTime: props.dayEnd && type.value === "datetimerange" ? timeRange : null
    };
    return {
      realWidth,
      rangeDefaultConfig,
      type,
      timeRange,
      datePicker
    };
  },
  render() {
    var _a, _b;
    return createVNode(resolveComponent("el-date-picker"), mergeProps({
      "value-format": (_a = this.datePicker) == null ? void 0 : _a.valueFormat,
      "style": {
        width: this.realWidth
      }
    }, {
      ...((_b = this.type) == null ? void 0 : _b.includes("range")) ? this.rangeDefaultConfig : {},
      ...this.$attrs
    }), null);
  }
});

export { DatePicker as default };
//# sourceMappingURL=date-picker.mjs.map
