import { defineComponent, ref, computed, createVNode, resolveComponent, createTextVNode, mergeProps } from 'vue';
import { ElDialog } from 'element-plus';
import { FullScreen } from '@element-plus/icons-vue';

var Dialog = defineComponent({
  name: "BcDialog",
  emits: ["update:modelValue", "cancel", "submit"],
  props: {
    noFooter: Boolean,
    needFullscreen: Boolean
  },
  components: {
    ElDialog,
    FullScreen
  },
  setup(props, context) {
    const fullscreen = ref(false);
    const isFullscreen = computed(() => {
      if (props.needFullscreen) {
        return fullscreen.value;
      } else {
        return !!context.attrs.fullscreen || context.attrs.fullscreen === "";
      }
    });
    fullscreen.value = !!context.attrs.fullscreen;
    function handleFullScreen() {
      fullscreen.value = !fullscreen.value;
    }
    function handleCancel() {
      context.emit("update:modelValue", false);
      context.emit("cancel");
    }
    const footer = () => createVNode("footer", null, [createVNode(resolveComponent("el-button"), {
      "onClick": handleCancel
    }, {
      default: () => [createTextVNode("\u53D6\u6D88")]
    }), createVNode(resolveComponent("el-button"), {
      "onClick": () => context.emit("submit")
    }, {
      default: () => [createTextVNode("\u786E\u8BA4")]
    })]);
    const header = () => {
      var _a, _b, _c, _d, _e, _f;
      return createVNode("header", {
        "class": "bc-dialog-header"
      }, [(_f = (_e = (_b = (_a = context.slots).header) == null ? void 0 : _b.call(_a)) != null ? _e : (_d = (_c = context.slots).title) == null ? void 0 : _d.call(_c)) != null ? _f : createVNode("span", {
        "class": "text"
      }, [context.attrs.title]), props.needFullscreen && createVNode(resolveComponent("el-icon"), {
        "onClick": handleFullScreen,
        "style": "cursor: pointer;"
      }, {
        default: () => [createVNode(resolveComponent("full-screen"), null, null)]
      })]);
    };
    const dialog = () => createVNode(resolveComponent("el-dialog"), mergeProps({
      "close-on-click-modal": false,
      "fullscreen": fullscreen.value
    }, {
      "onUpdate:modelValue": (visible) => context.emit("update:modelValue", visible)
    }, context.attrs), {
      default: () => [createVNode(resolveComponent("el-scrollbar"), {
        "ref": "scrollbar",
        "class": ["bc-dialog-scrollbar", {
          "bc-dialog-is-fullscreen": isFullscreen.value
        }]
      }, {
        default: () => {
          var _a, _b;
          return [(_b = (_a = context.slots).default) == null ? void 0 : _b.call(_a)];
        }
      })],
      header,
      footer: () => {
        var _a, _b;
        return !props.noFooter && (((_b = (_a = context.slots) == null ? void 0 : _a.footer) == null ? void 0 : _b.call(_a)) || footer());
      }
    });
    return dialog;
  }
});

export { Dialog as default };
//# sourceMappingURL=dialog.mjs.map
