import { computed, shallowRef, watchEffect, createVNode, resolveComponent } from 'vue';

function useSelection(rowSelectionRef, configRef) {
  const {
    getRowKey,
    pageData
  } = configRef;
  const mergedRowSelection = computed(() => {
    var _a;
    const tmp = (_a = rowSelectionRef.value) != null ? _a : {};
    return {
      ...tmp
    };
  });
  const mergedSelectedKeys = computed(() => {
    return mergedRowSelection.value.selectedRowKeys;
  });
  const selectKeysState = computed(() => {
    return mergedSelectedKeys.value;
  });
  const derivedSelectedKey = computed(() => selectKeysState.value);
  const derivedSelectedKeySet = computed(() => {
    const keys = derivedSelectedKey.value;
    return new Set(keys);
  });
  const preserveRecords = shallowRef(new Map());
  const rowKeys = computed(() => {
    return pageData.value.map((item) => getRowKey(item)).filter((item) => !!item);
  });
  watchEffect(() => {
    updateRecordsCache(mergedSelectedKeys.value);
  });
  function updateRecordsCache(keys) {
    if (mergedRowSelection.value.preserveRowKeys) {
      const newCache = new Map();
      keys.forEach((key) => {
        let record = configRef.getRecordByKey(key);
        if (!record && preserveRecords.value.has(key)) {
          record = preserveRecords.value.get(key);
        }
        newCache.set(key, record);
      });
      preserveRecords.value = newCache;
    }
  }
  function setSelectedKeys(keys, record) {
    let avaliableKeys = [];
    let records = [];
    updateRecordsCache(keys);
    const {
      preserveRowKeys,
      onChange: onSelectionChange
    } = mergedRowSelection.value;
    if (preserveRowKeys) {
      avaliableKeys = keys;
      records = keys.map((key) => preserveRecords.value.get(key));
    } else {
      keys.forEach((key) => {
        const record2 = configRef.getRecordByKey(key);
        if (record2 !== void 0) {
          avaliableKeys.push(key);
          records.push(record2);
        }
      });
    }
    onSelectionChange == null ? void 0 : onSelectionChange(avaliableKeys, records, record);
  }
  function renderCell({
    row
  }, config) {
    const keySet = new Set(derivedSelectedKeySet.value);
    const key = getRowKey(row);
    function onRowSelect() {
      const rowkey = getRowKey(row);
      if (keySet.has(rowkey)) {
        keySet.delete(rowkey);
      } else {
        keySet.add(rowkey);
      }
      setSelectedKeys(Array.from(keySet), row);
    }
    return createVNode(resolveComponent("el-checkbox"), {
      "model-value": keySet.has(key),
      "onClick": (e) => e.stopPropagation(),
      "onChange": () => onRowSelect()
    }, null);
  }
  function renderTop() {
    const keySet = new Set(derivedSelectedKeySet.value);
    const disabledChecked = computed(() => rowKeys.value.length === 0);
    const checkedCurrentAll = computed(() => rowKeys.value.every((key) => keySet.has(key)));
    const checkedCurrentSome = computed(() => rowKeys.value.some((key) => keySet.has(key)));
    function onSelectAllChange() {
      if (checkedCurrentAll.value) {
        rowKeys.value.forEach((key) => {
          keySet.delete(key);
        });
      } else {
        rowKeys.value.forEach((key) => {
          if (!keySet.has(key)) {
            keySet.add(key);
          }
        });
      }
      setSelectedKeys(Array.from(keySet));
    }
    return createVNode(resolveComponent("el-checkbox"), {
      "model-value": checkedCurrentAll.value && !disabledChecked.value,
      "indeterminate": !checkedCurrentAll.value && checkedCurrentSome.value,
      "onChange": onSelectAllChange,
      "disabled": disabledChecked.value
    }, null);
  }
  return [renderCell, renderTop];
}

export { useSelection };
//# sourceMappingURL=useSelection.mjs.map
