function getValue(row, column, config = {}, disableTravel) {
  const emptyText = "";
  if (disableTravel) {
    return row[column] || emptyText;
  }
  function getPathValue(data, keys, index) {
    const key = keys[index];
    if (data[key] instanceof Object && !Array.isArray(data[key])) {
      return getPathValue(data[key], keys, index + 1);
    } else {
      return data[key];
    }
  }
  const path = column.split(".");
  let res = "";
  res = getPathValue(row, path, 0);
  if (Array.isArray(res) && res.length === 0) {
    res = "";
  }
  if (res !== "" && res != null) {
    if (config.unit) {
      res = res + config.unit;
    }
    return filterValue(res, config.filter);
  }
  return filterValue(emptyText, config.filter);
}
function filterValue(val, filter) {
  if (!filter) {
    return val;
  }
  if (typeof filter === "function") {
    return filter(val);
  } else {
    return filter[val];
  }
}
function setValue(row, property, value) {
  const path = property.split(".");
  const lastKey = path[path.length - 1];
  const parent = getParent(row, path, 0);
  parent[lastKey] = value;
  function getParent(data, keys, index) {
    const key = keys[index];
    if (data[key] instanceof Object && !Array.isArray(data[key])) {
      return getParent(data[key], keys, index + 1);
    } else {
      return data;
    }
  }
}
function copyText(text) {
  return new Promise((resolve, reject) => {
    try {
      navigator.clipboard.writeText(text).then(() => {
        resolve(true);
      });
    } catch (err) {
      console.error(err);
      reject(err);
      const input = document.createElement("input");
      input.value = text;
      document.body.appendChild(input);
      input.select();
      document.execCommand("copy");
      input.style.display = "none";
      document.body.removeChild(input);
      resolve(true);
    }
  });
}
function extractObject(obj, keys, action = "include") {
  const res = {};
  for (const key in obj) {
    if (action === "include") {
      res[key] = obj[key];
    }
    if (action === "exclude") {
      if (keys.includes(key)) {
        continue;
      } else {
        res[key] = obj[key];
      }
    }
  }
  return res;
}
function toCamel(name) {
  const token = name.split("-");
  return token.map((item, index) => {
    if (index === 0) {
      return item;
    }
    return item.replace(/(.)/, (letter) => letter.toUpperCase());
  }).join("");
}

export { copyText, extractObject, getValue, setValue, toCamel };
//# sourceMappingURL=tools.mjs.map
