'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var type = require('./type.js');
var iconsVue = require('@element-plus/icons-vue');
var elementPlus = require('element-plus');
require('../../../utils/index.js');
var tools = require('../../../utils/tools.js');

var Input = vue.defineComponent({
  name: "BcInput",
  props: type.inputProps,
  inheritAttrs: false,
  components: {
    DocumentCopy: iconsVue.DocumentCopy,
    ElInput: elementPlus.ElInput
  },
  setup(props, context) {
    const inputRef = vue.ref();
    const inputWidth = vue.computed(() => {
      if (typeof props.width === "number") {
        return `${props.width}px`;
      }
      return props.width;
    });
    const borderClass = {
      none: "no-border",
      bottom: "bottom-border",
      all: ""
    }[props.border];
    const copyOptions = typeof props.copy === "boolean" ? {
      size: 20
    } : props.copy;
    const suffix = () => {
      var _a, _b;
      return vue.createVNode(vue.Fragment, null, [props.copy && vue.createVNode(vue.resolveComponent("el-tooltip"), {
        "content": "\u590D\u5236"
      }, {
        default: () => {
          var _a2;
          return [vue.createVNode(vue.resolveComponent("el-icon"), {
            "style": "cursor: pointer",
            "size": (_a2 = copyOptions.size) != null ? _a2 : 20,
            "color": copyOptions.color,
            "onClick": handleCopy
          }, {
            default: () => {
              var _a3, _b2, _c;
              return [(_c = (_b2 = (_a3 = context.slots).icon) == null ? void 0 : _b2.call(_a3)) != null ? _c : vue.createVNode(vue.resolveComponent("document-copy"), null, null)];
            }
          })];
        }
      }), (_b = (_a = context.slots).suffix) == null ? void 0 : _b.call(_a)]);
    };
    async function handleCopy() {
      var _a, _b;
      if (inputRef.value) {
        const text = (_b = (_a = inputRef.value.input) == null ? void 0 : _a.value) != null ? _b : "";
        await tools.copyText(String(text));
        elementPlus.ElMessage.success("\u590D\u5236\u6210\u529F");
      }
    }
    return {
      inputRef,
      borderClass,
      inputWidth,
      suffix
    };
  },
  render() {
    const input = () => vue.createVNode(vue.resolveComponent("el-input"), vue.mergeProps({
      "ref": (el) => this.inputRef = el,
      "class": ["bc-input", this.borderClass],
      "style": {
        width: this.inputWidth
      },
      "placeholder": "\u8BF7\u8F93\u5165",
      "spellcheck": false
    }, this.$attrs), {
      ...this.$slots,
      suffix: this.suffix
    });
    const text = () => vue.createVNode("span", null, [this.$attrs.modelValue]);
    return this.onlyDisplay ? text() : input();
  }
});

exports["default"] = Input;
//# sourceMappingURL=input.js.map
