'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../utils/index.js');
var type = require('./type.js');
require('../../../hooks/index.js');
var elementPlus = require('element-plus');
var pluginVue_exportHelper = require('../../../_virtual/plugin-vue_export-helper.js');
var useConfigInject = require('../../../hooks/useConfigInject.js');
var tools = require('../../../utils/tools.js');

const _sfc_main = vue.defineComponent({
  name: "BcSelect",
  emits: ["update:modelValue", "update:label", "fetch", "change"],
  props: type.selectProps,
  components: {
    ElSelect: elementPlus.ElSelect
  },
  setup(props, context) {
    const { arrayName, label: optionLabel, value: optionValue, response } = useConfigInject.useConfigInject("select", props);
    const optionsName = vue.computed(() => (props.arrayName || arrayName.value) ?? "");
    const responseWrap = vue.computed(() => response.value?.data ?? "data");
    const apiOptions = vue.ref([]);
    const selectOptions = vue.computed(() => {
      return [...props.options || apiOptions.value || []];
    });
    const needGroup = vue.computed(() => {
      if (!props.group) {
        return false;
      }
      return selectOptions.value.some((item) => item.children);
    });
    const displayText = vue.computed(() => {
      const value = Array.isArray(props.modelValue) ? props.modelValue : [props.modelValue];
      const res = [];
      value.forEach((item) => {
        let obj = {};
        if (props.modelValue instanceof Object) {
          obj = props.modelValue;
        } else {
          obj = selectOptions.value.find((each) => each[optionValue.value] === item) || {};
        }
        res.push(obj ? obj[optionLabel.value] : "");
      });
      return res.join(",");
    });
    const selectWidth = vue.computed(() => {
      if (!props.width) {
        return "";
      }
      if (typeof props.width === "string") {
        return props.width;
      } else {
        return props.width + "px";
      }
    });
    props.immediate && getList();
    props.defaultValue && context.emit("update:modelValue", props.defaultValue);
    function getList() {
      if (typeof props.api === "function") {
        props.api().then((data) => {
          if (data[responseWrap.value]) {
            apiOptions.value = data[responseWrap.value][optionsName.value] || data[responseWrap.value];
          }
          context.emit("fetch", apiOptions.value);
        });
      }
    }
    function hasValue(item) {
      const value = tools.getValue(item, optionLabel.value);
      if (value === "" || !!value) {
        return value;
      } else {
        return typeof item === "object" ? "" : item;
      }
    }
    function getObject(value) {
      if (typeof value === "object") {
        return value;
      }
      const res = selectOptions.value.find((item) => item[optionValue.value] === (value || props.modelValue));
      if (!res) {
        return {};
      }
      return res;
    }
    function getLabel(val) {
      const value = val || props.modelValue;
      if (Array.isArray(value)) {
        return value.reduce((res, curr) => {
          const result = selectOptions.value.find((item) => item[optionValue.value] === curr) || {};
          if (!result) {
            res.push("");
          }
          res.push(result[optionLabel.value]);
          return res;
        }, []);
      } else {
        const res = selectOptions.value.find((item) => item[optionValue.value] === value);
        if (!res) {
          return "";
        }
        return res[optionLabel.value];
      }
    }
    function getOptions() {
      return selectOptions.value;
    }
    function emitValue(val) {
      context.emit("update:modelValue", val);
      context.emit("change", val, getObject(val));
    }
    function emitLabel(val) {
      context.emit("update:label", getLabel(val));
    }
    context.expose({
      getOptions,
      getLabel
    });
    return {
      needGroup,
      displayText,
      selectOptions,
      selectWidth,
      optionValue,
      hasValue,
      getObject,
      getLabel,
      getOptions,
      emitLabel,
      emitValue
    };
  }
});
const _hoisted_1 = { key: 1 };
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_el_option = vue.resolveComponent("el-option");
  const _component_el_option_group = vue.resolveComponent("el-option-group");
  const _component_el_select = vue.resolveComponent("el-select");
  return !_ctx.onlyDisplay ? (vue.openBlock(), vue.createBlock(_component_el_select, vue.mergeProps({
    key: 0,
    "model-value": _ctx.modelValue,
    "onUpdate:modelValue": _ctx.emitValue,
    onChange: _ctx.emitLabel,
    style: { width: _ctx.selectWidth }
  }, { clearable: true, valueKey: _ctx.optionKey, ..._ctx.$attrs }), {
    default: vue.withCtx(() => [
      _ctx.needGroup ? (vue.openBlock(true), vue.createElementBlock(vue.Fragment, { key: 0 }, vue.renderList(_ctx.selectOptions, (groupOptions, index) => {
        return vue.openBlock(), vue.createBlock(_component_el_option_group, {
          key: index,
          label: _ctx.hasValue(groupOptions),
          value: groupOptions[_ctx.optionValue] == null ? groupOptions : groupOptions[_ctx.optionValue]
        }, {
          default: vue.withCtx(() => [
            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(groupOptions.children, (item) => {
              return vue.openBlock(), vue.createBlock(_component_el_option, {
                key: item[_ctx.optionKey || _ctx.optionValue],
                label: _ctx.hasValue(item),
                value: item[_ctx.optionValue] == null ? item : item[_ctx.optionValue],
                disabled: _ctx.itemDisabled && _ctx.itemDisabled(item)
              }, {
                default: vue.withCtx(() => [
                  vue.renderSlot(_ctx.$slots, "default", vue.normalizeProps(vue.guardReactiveProps({ ...item })))
                ]),
                _: 2
              }, 1032, ["label", "value", "disabled"]);
            }), 128))
          ]),
          _: 2
        }, 1032, ["label", "value"]);
      }), 128)) : (vue.openBlock(true), vue.createElementBlock(vue.Fragment, { key: 1 }, vue.renderList(_ctx.selectOptions, (item) => {
        return vue.openBlock(), vue.createBlock(_component_el_option, {
          key: item[_ctx.optionKey || _ctx.optionValue],
          label: _ctx.hasValue(item),
          value: item[_ctx.optionValue] == null ? item : item[_ctx.optionValue],
          disabled: _ctx.itemDisabled && _ctx.itemDisabled(item)
        }, {
          default: vue.withCtx(() => [
            vue.renderSlot(_ctx.$slots, "default", vue.normalizeProps(vue.guardReactiveProps({ ...item })))
          ]),
          _: 2
        }, 1032, ["label", "value", "disabled"]);
      }), 128))
    ]),
    _: 3
  }, 16, ["model-value", "onUpdate:modelValue", "onChange", "style"])) : (vue.openBlock(), vue.createElementBlock("span", _hoisted_1, vue.toDisplayString(_ctx.displayText), 1));
}
var Select = /* @__PURE__ */ pluginVue_exportHelper["default"](_sfc_main, [["render", _sfc_render]]);

exports["default"] = Select;
//# sourceMappingURL=select.js.map
