'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');

var cellEdit = vue.defineComponent({
  name: "BcTableCellEdit",
  emits: ["save", "blur"],
  directives: {
    focus: {
      mounted: (el) => {
        el.querySelector("input").focus();
      }
    }
  },
  props: {
    modelValue: {
      type: [String, Number],
      default: ""
    },
    unit: String
  },
  setup(props, context) {
    const editing = vue.ref(false);
    const cell = vue.ref("");
    const inputRef = vue.ref();
    function toggleEdit() {
      editing.value = !editing.value;
    }
    function save() {
      context.emit("save", cell.value);
      const el = inputRef.value.$el;
      el == null ? void 0 : el.querySelector("input").blur();
    }
    const editInput = () => vue.withDirectives(vue.createVNode(vue.resolveComponent("bc-input"), vue.mergeProps({
      "class": "bc-table-input",
      "ref": inputRef,
      "model-value": cell.value
    }, {
      "onUpdate:modelValue": (val) => {
        cell.value = val;
      },
      onFocus: () => {
        cell.value = props.modelValue;
      },
      onBlur: () => {
        toggleEdit();
        context.emit("blur", cell.value);
      },
      onKeyup: (e) => {
        e.code === "Enter" && save();
      }
    }), {
      suffix: props.unit ? vue.createVNode("span", null, [props.unit]) : null
    }), [[vue.resolveDirective("focus")]]);
    const displayInput = () => vue.createVNode("div", {
      "class": "bc-table-cell-edit",
      "onClick": toggleEdit
    }, [props.modelValue]);
    return () => editing.value ? editInput() : displayInput();
  }
});

exports["default"] = cellEdit;
//# sourceMappingURL=cellEdit.js.map
